@@ -15,7 +15,13 @@ __all__ = [
 ]
 
 from tango.executor import Executor, SimpleExecutor
-from tango.format import Format, DillFormat, DillFormatIterator, JsonFormat, JsonFormatIterator
+from tango.format import (
+    DillFormat,
+    DillFormatIterator,
+    Format,
+    JsonFormat,
+    JsonFormatIterator,
+)
 from tango.step import Step
-from tango.step_cache import StepCache, LocalStepCache
+from tango.step_cache import LocalStepCache, StepCache
 from tango.step_graph import StepGraph, StepStub
