@@ -60,19 +60,19 @@ such as which integrations are available.
 
 """
 
+import os
 from dataclasses import dataclass
 from pathlib import Path
-import os
-from typing import Optional, Union, List, Sequence
+from typing import List, Optional, Sequence, Union
 
 import click
 from click_help_colors import HelpColorsCommand, HelpColorsGroup
 
-from tango.version import VERSION
-from tango.common.from_params import FromParams
 import tango.common.logging as common_logging
+from tango.common.aliases import PathOrStr
+from tango.common.from_params import FromParams
 from tango.common.params import Params
-from tango.common.util import PathOrStr, install_sigterm_handler
+from tango.version import VERSION
 
 
 @dataclass
@@ -182,9 +182,6 @@ def main(
         log_level=log_level, file_friendly_logging=file_friendly_logging
     )
 
-    # We want to be able to catch SIGTERM signals in addition to SIGINT (keyboard interrupt).
-    install_sigterm_handler()
-
     ctx.obj = config
 
 
@@ -262,7 +259,7 @@ def info(config: TangoGlobalSettings):
     # Show info about config.
     if config.path is not None:
         click.echo("\nConfig:")
-        click.secho(f" ✓ Loaded from {str(config.path)}", fg="green")
+        click.secho(f" \N{check mark} Loaded from {str(config.path)}", fg="green")
         if config.include_package:
             click.echo("\n   Included packages:")
             for package in config.include_package:
@@ -272,9 +269,9 @@ def info(config: TangoGlobalSettings):
                 except (ModuleNotFoundError, ImportError):
                     is_found = False
                 if is_found:
-                    click.secho(f"   ✓ {package}", fg="green")
+                    click.secho(f"   \N{check mark} {package}", fg="green")
                 else:
-                    click.secho(f"   ✗ {package}", fg="red")
+                    click.secho(f"   \N{ballot x} {package} (not found)", fg="red")
 
     # Show info about integrations.
     click.echo("\nIntegrations:")
@@ -286,9 +283,9 @@ def info(config: TangoGlobalSettings):
         except (ModuleNotFoundError, ImportError):
             is_installed = False
         if is_installed:
-            click.secho(f" ✓ {name}", fg="green")
+            click.secho(f" \N{check mark} {name}", fg="green")
         else:
-            click.secho(f" ✗ {name}", fg="yellow")
+            click.secho(f" \N{ballot x} {name} (not installed)", fg="yellow")
 
 
 def _run(
