@@ -1,26 +1,35 @@
 import collections.abc
+import inspect
+import logging
 from copy import deepcopy
 from pathlib import Path
 from typing import (
     Any,
     Callable,
-    cast,
     Dict,
     Iterable,
     List,
     Mapping,
+    Optional,
     Set,
     Tuple,
     Type,
     TypeVar,
     Union,
-    Optional,
+    cast,
 )
-import inspect
-import logging
 
+try:
+    # For PEP 604 support (python >= 3.10)
+    from types import UnionType  # type: ignore[attr-defined]
+except ImportError:
+
+    class UnionType:  # type: ignore
+        pass
+
+
+from ._det_hash import CustomDetHash
 from .exceptions import ConfigurationError
-from .det_hash import CustomDetHash
 from .lazy import Lazy
 from .params import Params
 
@@ -88,7 +97,9 @@ def is_base_registrable(cls) -> bool:
     Checks whether this is a class that directly inherits from Registrable, or is a subclass of such
     a class.
     """
-    from tango.common.registrable import Registrable  # import here to avoid circular imports
+    from tango.common.registrable import (
+        Registrable,  # import here to avoid circular imports
+    )
 
     if not issubclass(cls, Registrable):
         return False
@@ -222,6 +233,8 @@ def create_kwargs(
     if accepts_kwargs:
         for key in list(params):
             kwargs[key] = params.pop(key, keep_as_dict=True)
+        for key, value in extras.items():
+            kwargs[key] = value
     params.assert_empty(cls.__name__)
     return kwargs
 
@@ -316,12 +329,12 @@ def construct_arg(
     # The parameter is optional if its default value is not the "no default" sentinel.
     optional = default != _NO_DEFAULT
 
-    if hasattr(annotation, "from_params"):
+    if inspect.isclass(annotation) and issubclass(annotation, FromParams):
         if popped_params is default:
             return default
+        elif origin is None and isinstance(popped_params, annotation):
+            return popped_params
         elif popped_params is not None:
-            # Our params have an entry for this, so we use that.
-
             subextras = create_extras(annotation, extras)
 
             # In some cases we allow a string instead of a param dict, so
@@ -335,6 +348,12 @@ def construct_arg(
                     popped_params = Params({"type": popped_params})
             elif isinstance(popped_params, dict):
                 popped_params = Params(popped_params)
+            elif not isinstance(popped_params, Params):
+                raise TypeError(
+                    f"Expected a `Params` object, found `{popped_params}` instead while constructing "
+                    f"parameter '{argument_name}' for `{class_name}`"
+                )
+
             result = annotation.from_params(popped_params, **subextras)
 
             if isinstance(result, Step):
@@ -454,7 +473,7 @@ def construct_arg(
 
         return value_set
 
-    elif origin == Union:
+    elif origin == Union or isinstance(annotation, UnionType):
         # Storing this so we can recover it later if we need to.
         backup_params = deepcopy(popped_params)
 
@@ -490,8 +509,7 @@ def construct_arg(
             return default
 
         value_cls = args[0]
-        subextras = create_extras(value_cls, extras)
-        return Lazy(value_cls, params=deepcopy(popped_params), constructor_extras=subextras)  # type: ignore
+        return Lazy(value_cls, params=deepcopy(popped_params))  # type: ignore
 
     # For any other kind of iterable, we will just assume that a list is good enough, and treat
     # it the same as List. This condition needs to be at the end, so we don't catch other kinds
@@ -518,6 +536,13 @@ def construct_arg(
 
         return value_list
 
+    elif inspect.isclass(annotation) and isinstance(popped_params, Params):
+        subextras = create_extras(annotation, extras)
+        constructor_to_inspect = annotation.__init__
+        constructor_to_call = annotation
+        kwargs = create_kwargs(constructor_to_inspect, annotation, popped_params, **subextras)
+        return constructor_to_call(**kwargs)  # type: ignore
+
     else:
         # Pass it on as is and hope for the best.   ¯\_(ツ)_/¯
         if isinstance(popped_params, Params):
@@ -528,7 +553,7 @@ def construct_arg(
 class FromParams(CustomDetHash):
     """
     Mixin to give a :meth:`from_params` method to classes. We create a distinct base class for this
-    because sometimes we want non :class:`~tango.common.registrable.Registrable`
+    because sometimes we want non :class:`~tango.common.Registrable`
     classes to be instantiatable ``from_params``.
     """
 
@@ -542,7 +567,7 @@ class FromParams(CustomDetHash):
     ) -> T:
         """
         This is the automatic implementation of ``from_params``. Any class that subclasses
-        from ``FromParams`` (or :class:`~tango.common.registrable.Registrable`,
+        from ``FromParams`` (or :class:`~tango.common.Registrable`,
         which itself subclasses ``FromParams``) gets this
         implementation for free.  If you want your class to be instantiated from params in the
         "obvious" way -- pop off parameters and hand them to your constructor with the same names --
@@ -563,7 +588,9 @@ class FromParams(CustomDetHash):
         constructor (because you inspect ``__init__``, but call ``cls()``).
         """
 
-        from tango.common.registrable import Registrable  # import here to avoid circular imports
+        from tango.common.registrable import (
+            Registrable,  # import here to avoid circular imports
+        )
 
         params = params_
 
