@@ -1,35 +1,35 @@
-from abc import abstractmethod
-from dataclasses import dataclass, field
 import getpass
 import logging
 import os
-from pathlib import Path
 import platform
-import time
-from typing import List, Tuple, Iterable, Any, Dict, Optional
 import socket
 import sys
+import time
+from abc import abstractmethod
+from dataclasses import dataclass, field
+from pathlib import Path
+from typing import Any, Dict, Iterable, List, Optional, Tuple
 
 import click
 
+from tango.common.aliases import PathOrStr
 from tango.common.file_lock import FileLock
 from tango.common.from_params import FromParams
 from tango.common.params import Params
 from tango.common.registrable import Registrable
-from tango.common.util import PathOrStr, import_module_and_submodules
+from tango.common.util import import_module_and_submodules
 from tango.step import Step
 from tango.step_cache import StepCache
 from tango.step_graph import StepGraph, StepStub
 from tango.version import VERSION
 
-
 logger = logging.getLogger(__name__)
 
 
 class Executor(Registrable):
     """
-    An ``Executor`` is a :class:`~tango.common.registrable.Registrable` class that is
-    responsible for running steps and returning them with their result.
+    An ``Executor`` is a :class:`~tango.common.Registrable` class that is
+    responsible for running steps and caching their results.
 
     Subclasses should implement :meth:`execute_step_group()`.
     """
@@ -89,7 +89,7 @@ class Executor(Registrable):
                     else:
                         executed[step.name] = (step, None)
                         click.echo(
-                            click.style("✓ Found output for ", fg="green")
+                            click.style("\N{check mark} Found output for ", fg="green")
                             + click.style(f'"{step.name}"', bold=True, fg="green")
                             + click.style(" in cache", fg="green")
                         )
@@ -146,7 +146,7 @@ class Executor(Registrable):
                         target_is_directory=True,
                     )
                     click.echo(
-                        click.style("✓ The output for ", fg="green")
+                        click.style("\N{check mark} The output for ", fg="green")
                         + click.style(f'"{name}"', bold=True, fg="green")
                         + click.style(" is in ", fg="green")
                         + click.style(f"{step_link}", bold=True, fg="green")
@@ -179,8 +179,8 @@ class Executor(Registrable):
         """
         if not quiet:
             click.echo(
-                click.style("● Starting run for ", fg="blue")
-                + click.style(f'"{step.name}"', bold=True, fg="blue")
+                click.style("\N{black circle} Starting run for ", fg="blue")
+                + click.style(f'"{step.name}"...', bold=True, fg="blue")
             )
 
         # Initialize metadata.
@@ -204,7 +204,7 @@ class Executor(Registrable):
 
         if not quiet:
             click.echo(
-                click.style("✓ Finished run for ", fg="green")
+                click.style("\N{check mark} Finished run for ", fg="green")
                 + click.style(f'"{step.name}"', bold=True, fg="green")
             )
 
@@ -321,7 +321,9 @@ class GitMetadata(FromParams):
 
         try:
             commit = (
-                subprocess.check_output("git rev-parse HEAD".split(" ")).decode("ascii").strip()
+                subprocess.check_output("git rev-parse HEAD".split(" "), stderr=subprocess.DEVNULL)
+                .decode("ascii")
+                .strip()
             )
             remote: Optional[str] = None
             for line in (
