@@ -22,10 +22,11 @@ from tango.format import Format
 from tango.step import Step
 
 from .data import DataLoader
+from .exceptions import StopEarly
 from .format import TorchFormat
 from .model import Model
 from .optim import LRScheduler, Optimizer
-from .train_callback import StopEarly, TrainCallback
+from .train_callback import TrainCallback
 
 
 @Step.register("torch::train")
@@ -85,6 +86,7 @@ class TorchTrainStep(Step):
         minimize_val_metric: bool = True,
         aggregate_val_metric: bool = True,
         callbacks: Optional[List[Lazy[TrainCallback]]] = None,
+        remove_state_checkpoints: bool = True,
     ) -> Model:
         """
         Run a basic training loop to train the ``model``.
@@ -159,8 +161,11 @@ class TorchTrainStep(Step):
             validation batches and distributed processes. This may not be the correct
             behavior for some metrics (such as F1), in which you should set this to
             ``False`` and handle the aggregation internally in your model.
-        callbacks: ``List[TrainCallback]``
+        callbacks : ``List[TrainCallback]``
             A list of :class:`TrainCallback`.
+        remove_stale_checkpoints : :class:`bool`
+            If ``True`` (the default), stale checkpoints will be removed throughout training so that
+            only the latest and best checkpoints are kept.
 
         Returns
         -------
@@ -227,6 +232,7 @@ class TorchTrainStep(Step):
                     minimize_val_metric,
                     aggregate_val_metric,
                     callbacks,
+                    remove_state_checkpoints,
                 ),
                 nprocs=num_workers,
             )
@@ -258,6 +264,7 @@ class TorchTrainStep(Step):
                 minimize_val_metric=minimize_val_metric,
                 aggregate_val_metric=aggregate_val_metric,
                 callbacks=callbacks,
+                remove_state_checkpoints=remove_state_checkpoints,
             )
             assert final_model is not None
             final_model = final_model.cpu()
@@ -300,6 +307,7 @@ def _train(
     minimize_val_metric: bool = True,
     aggregate_val_metric: bool = True,
     callbacks: Optional[List[Lazy[TrainCallback]]] = None,
+    remove_state_checkpoints: bool = True,
 ) -> Optional[Model]:
     if include_package:
         from tango.common.util import import_module_and_submodules
@@ -428,13 +436,18 @@ def _train(
             work_dir=work_dir,
             model=model,
             optimizer=optimizer,
+            dataset_dict=dataset_dict,
             train_dataloader=train_dataloader,
+            train_steps=train_steps,
+            validation_steps=validation_steps,
             validation_dataloader=validation_dataloader,
             lr_scheduler=lr_scheduler,
             is_local_main_process=is_local_main_process,
             worker_id=worker_id,
             world_size=world_size,
             device=device,
+            val_metric_name=val_metric_name,
+            minimize_val_metric=minimize_val_metric,
         )
         for callback in (callbacks or [])
     ]
@@ -537,6 +550,14 @@ def _train(
                             best_state_path.unlink()
                         best_state_path.symlink_to(state_path_for_step)
 
+                    # Clean up stale checkpoints.
+                    if remove_state_checkpoints:
+                        checkpoints_to_keep = {best_state_path.resolve(), state_path.resolve()}
+                        for path in work_dir.glob(f"state_worker{worker_id}_*.pt"):
+                            path = path.resolve()
+                            if path not in checkpoints_to_keep:
+                                path.unlink()
+
                     for callback in callbacks:  # type: ignore[union-attr]
                         callback.post_checkpoint(state_path_for_step)  # type: ignore[union-attr]
                 finally:
@@ -684,9 +705,6 @@ def _train(
 
                 assert val_metric is not None
 
-                for callback in callbacks:
-                    callback.post_val_loop(step, val_metric_name, val_metric)
-
                 # Reset model to train mode.
                 model.train()
 
@@ -697,6 +715,9 @@ def _train(
                 elif not minimize_val_metric and val_metric >= best_val_metric:
                     best_val_metric = val_metric
 
+                for callback in callbacks:
+                    callback.post_val_loop(step, val_metric, best_val_metric)
+
                 # Update progress bar again.
                 metrics_to_log = {
                     "batch_loss": batch_loss,
